package logger

import (
	"fmt"
	"io"
	"os"
	"time"

	"github.com/rs/zerolog/log"
	"gopkg.in/natefinch/lumberjack.v2"
)

func newRollingWriter() io.Writer {
	if err := os.MkdirAll("log", 0744); err != nil {
		log.Error().Err(err).Str("path", "./log").Msg("不能创建用于保存日志的目录。")
		return nil
	}

	now := time.Now()

	return &lumberjack.Logger{
		Filename:   fmt.Sprintf("log/%04d-%02d-%02d.log", now.Year(), now.Month(), now.Day()),
		MaxBackups: 0,   // files
		MaxSize:    200, // megabytes
		MaxAge:     0,   // days
	}
}
